pub fn run_case(case: &TestCase, ctx: &Ctx<'_>) -> CaseResultExpand description
Execute one case, timing it and converting panics into an Error status.
pub fn run_case(case: &TestCase, ctx: &Ctx<'_>) -> CaseResultExecute one case, timing it and converting panics into an Error status.